# Modeling SAP Interfaces and External Partners
Learn how to model SAP Interfaces and External Partners.
Interfaces (i.e., internal or external system dependencies) can be critical, especially in ERP transformations and operations. We recommend modeling 'business' interfaces in SAP LeanIX (those understood by business or key stakeholders) and also linking technical information in the resources tab, such as diagrams or other technical documentation. Important attributes to consider when modeling interfaces include responsibilities, technology dependencies, and security information.
Data maintenance can be handled collaboratively and through automated solutions, like automation and survey features. The interface circle map is a useful tool for visualizing dependencies during implementation.
To learn about automation and surveys, see [Automations](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD "Configure no-code automations to streamline your workflows.") and [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets."). To learn how to add resources to the fact sheet, see [Storing Resources on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio27592c207a441014b142ca56bfa9decf__storing_resources_on_fact_sheets).
![Visualizing Dependencies with Circle Map](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275399fa7a44101488429c242aba21c2_LowRes.png)
Visualizing Dependencies with Circle Map
When modeling external partners, you have different options:
  * Cluster external partner dependencies: Create one or more application fact sheets to group external partner dependencies. You can add IT components and provider fact sheets as needed. This approach is ideal when the dependencies are of low strategic importance. It also allows you to use the same data objects and interfaces for multiple partners.
  * Model external partners as separate applications: Model each external partner as an individual application with specific interfaces. This approach is suitable when dependencies are highly strategic and need individual visualization. It allows for more detailed modeling of each partner's impact and relationships.
